@@ -1,12 +1,12 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gog-view.h : A sized render engine for an item.
  *
  * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -85,8 +85,8 @@ typedef struct {
 	void	 (*padding_request) 		(GogView *view, GogViewAllocation const *bbox,
 						 GogViewPadding *padding);
 	void	 (*size_request)    		(GogView *view, GogViewRequisition const *available,
-						 GogViewRequisition *req);
-	void	 (*size_allocate)   		(GogView *, GogViewAllocation const *bbox);
+						 GogViewRequisition *requisition);
+	void	 (*size_allocate)   		(GogView *view, GogViewAllocation const *allocation);
 
 	void	 (*render)        		(GogView *view, GogViewAllocation const *bbox);
 
